@@ -1,15 +1,15 @@
 package jp.ac.takushoku_u.cs;
 
 /**
-* NotElementException饹¸ߤʤֹꤷȤ򼨤˥ޤ
-* @version 1.1
+* NotElementException饹¸ߤʤǤꤷȤ򼨤˥ޤ
+* @version 1.2
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ0927
+* ǽ 2004ǯ1209
 */
 
-public class NotElementException extends OutOfBoundsException{
+public class NotElementException extends NotIndexException{
 
 /**
 * åʤ NotElementException ۤޤ
