@@ -2,18 +2,18 @@ package jp.ac.takushoku_u.cs;
 
 /**
 * SPTable饹S-PɽԤ饹Ǥ
-* @version 1.0
+* @version 1.1.1
 * @author  ͵(Kasajima Hiroshi)
 */
 /*
-* ǽ 2004ǯ1029
+* ǽ 2004ǯ1206
 */
 public class SPTable{
 	
 /**
 * SPɽΥǡݻޥȥꥯ
 */
-	private Matrix matrix;
+	private ArithmeticMatrix matrix;
 	
 /**
 * ¤ؤ塢ιԤϸϲܤǤäֹݻ
@@ -41,21 +41,33 @@ public class SPTable{
 	private static final double SPTABLE_CAUTION_MARK_CAUTION_VALUE2 = 0.75;
 	
 /**
-* եޡɽʤɽ
+* եޡɽʤ򼨤ɽ
 */
 	private static final int SPTABLE_CAUTION_MARK_NON = 0;
+	
+/**
+* եޡɽʤɽ
+*/
 	private static final String SPTABLE_CAUTION_MARK_NONSTRING = "";
 	
+/**
+* եޡ``!''򼨤ɽ
+*/
+	private static final int SPTABLE_CAUTION_MARK_ONE = 1;
+	
 /**
 * եޡ``!''ɽɽ
 */
-	private static final int SPTABLE_CAUTION_MARK_ONE = 1;
 	private static final String SPTABLE_CAUTION_MARK_ONESTRING = "!";
 	
+/**
+* եޡ''!!``򼨤ɽ
+*/
+	private static final int SPTABLE_CAUTION_MARK_TWO = 2;
+	
 /**
 * եޡ''!!``ɽɽ
 */
-	private static final int SPTABLE_CAUTION_MARK_TWO = 2;
 	private static final String SPTABLE_CAUTION_MARK_TWOSTRING = "!!";
 	
 /**
@@ -69,7 +81,7 @@ public class SPTable{
 * ޥȥꥯǤ0Ȥʤޤ
 */
 	public SPTable(){
-		Matrix baseMatrix = new Matrix(SPTABLE_MATRIX_VALUE, SPTABLE_MATRIX_VALUE);
+		ArithmeticMatrix baseMatrix = new ArithmeticMatrix(SPTABLE_MATRIX_VALUE, SPTABLE_MATRIX_VALUE);
 		setSPMatrix(baseMatrix);
 	}
 	
@@ -77,7 +89,7 @@ public class SPTable{
 * S-PɽޥȥꥯꤷʬϤԤޤ
 * @param baseMatrix SPɽޥȥꥯ
 */
-	public SPTable(Matrix baseMatrix){
+	public SPTable(ArithmeticMatrix baseMatrix){
 		setSPMatrix(baseMatrix);
 	}
 	
@@ -86,14 +98,14 @@ public class SPTable{
 * @return S-Pɽ
 * @see #getSPFullMatrix()
 */
-	public Matrix getSPMatrix(){
+	public ArithmeticMatrix getSPMatrix(){
 		baseRow = arrangeArray(matrix.getRowSumArray());
 		baseCol = arrangeArray(matrix.getColSumArray());
 		
-		Matrix changeMatrix = new Matrix();
-		changeMatrix.MatrixCopy(matrix);
-		changeMatrix.MatrixCopy(getStudentChangeMatrix(matrix, baseRow));
-		changeMatrix.MatrixCopy(getProblemChangeMatrix(changeMatrix, baseCol));
+		ArithmeticMatrix changeMatrix = new ArithmeticMatrix();
+		changeMatrix.matrixCopy(matrix);
+		changeMatrix.matrixCopy(getStudentChangeMatrix(matrix, baseRow));
+		changeMatrix.matrixCopy(getProblemChangeMatrix(changeMatrix, baseCol));
 		
 		//¤ؤ̤S-Pɽɲ
 		for (int i = 0; i < changeMatrix.getRowLength(); i++){
@@ -110,10 +122,12 @@ public class SPTable{
 * շͤޤ᤿S-Pɽ֤ޤ<BR>
 * ޥȥꥯԿΨշ͡եޡޤޤޤ
 * S-PɽΥޥȥꥯ٥4ԡ4ʬ礭ʤäƤޤ
+* եޡϿɽ졢`!'`1'`!!'`2'Ȥʤޤ
 * @return շͤޤ᤿S-Pɽ
 * @see #getSPMatrix()
+* @see #getSPStringMatrix()
 */
-	public Matrix getSPFullMatrix(){
+	public ArithmeticMatrix getSPFullMatrix(){
 		String rowName[] = new String[matrix.getRowLength()+4];
 		String colName[] = new String[matrix.getColLength()+4];
 		
@@ -129,12 +143,12 @@ public class SPTable{
 		colName[matrix.getColLength()+2] = "շ";
 		colName[matrix.getColLength()+3] = "եޡ";
 		
-		Matrix spFullMatrix = new Matrix(matrix.getRowLength()+4,matrix.getColLength()+4, rowName, colName);
-		Matrix spMatrix = new Matrix(matrix.getRowLength(), matrix.getColLength());
-		spMatrix.MatrixCopy(getSPMatrix());
+		ArithmeticMatrix spFullMatrix = new ArithmeticMatrix(matrix.getRowLength()+4,matrix.getColLength()+4, rowName, colName);
+		ArithmeticMatrix spMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength());
+		spMatrix.matrixCopy(getSPMatrix());
 		
 		//S-PɽΥԡ
-		spFullMatrix.MatrixCopy(spMatrix, 0, 0, 0, 0, spMatrix.getRowLength(), spMatrix.getColLength());
+		spFullMatrix.matrixCopy(spMatrix, 0, 0, 0, 0, spMatrix.getRowLength(), spMatrix.getColLength());
 		
 		//¦ν
 		for(int i = 0; i < spMatrix.getRowLength(); i++){
@@ -159,6 +173,61 @@ public class SPTable{
 		return spFullMatrix;
 	}
 	
+/**
+* շͤޤ᤿S-Pɽ֤ޤ<BR>
+* ޥȥꥯԿΨշ͡եޡޤޤޤ
+* S-PɽΥޥȥꥯ٥4ԡ4ʬ礭ʤäƤޤ
+* եޡ`!'`!!'ɽޤ
+* @return շͤޤ᤿S-Pɽ
+* @see #getSPMatrix()
+* @see #getSPFullMatrix()
+*/
+	public StringMatrix getSPStringMatrix(){
+		String rowName[] = new String[matrix.getRowLength()+4];
+		String colName[] = new String[matrix.getColLength()+4];
+		
+		System.arraycopy(matrix.getRowNameArray(), 0, rowName, 0, matrix.getRowLength());
+		System.arraycopy(matrix.getColNameArray(), 0, colName, 0, matrix.getColLength());
+		rowName[matrix.getRowLength()] = "Կ";
+		rowName[matrix.getRowLength()+1] = "Ψ";
+		rowName[matrix.getRowLength()+2] = "շ";
+		rowName[matrix.getRowLength()+3] = "եޡ";
+		
+		colName[matrix.getColLength()] = "";
+		colName[matrix.getColLength()+1] = "Ψ";
+		colName[matrix.getColLength()+2] = "շ";
+		colName[matrix.getColLength()+3] = "եޡ";
+		
+		StringMatrix spFullMatrix = new StringMatrix(matrix.getRowLength()+4,matrix.getColLength()+4, rowName, colName);
+		ArithmeticMatrix spMatrix = new ArithmeticMatrix(matrix.getRowLength(), matrix.getColLength());
+		spMatrix.matrixCopy(getSPMatrix());
+		
+		//S-PɽΥԡ
+		spFullMatrix.matrixCopy(spMatrix.toStringMatrix(), 0, 0, 0, 0, spMatrix.getRowLength(), spMatrix.getColLength());
+		
+		//¦ν
+		for(int i = 0; i < spMatrix.getRowLength(); i++){
+			spFullMatrix.setRowName(i, spMatrix.getRowName(i));		//̾ԡ
+			spFullMatrix.setCell(i,matrix.getColLength(),getStudentSum(getBaseRow(i))+"");		//
+			spFullMatrix.setCell(i,matrix.getColLength()+1,getStudentAverage(getBaseRow(i))+"");		//ʿΨ
+			spFullMatrix.setCell(i,matrix.getColLength()+2,getStudentAttentionCoefficient(getBaseRow(i))+"");		//շ
+			spFullMatrix.setCell(i,matrix.getColLength()+3, getStudentAttentionMark(getBaseRow(i)));		//եޡ
+		}
+		
+		//¦ν
+		for(int j = 0; j < spMatrix.getColLength(); j++){
+			spFullMatrix.setColName(j, spMatrix.getColName(j));		//̾ԡ
+			spFullMatrix.setCell(matrix.getRowLength(), j,getProblemSum(getBaseCol(j))+"");		//Կ
+			spFullMatrix.setCell(matrix.getRowLength()+1, j,getProblemAverage(getBaseCol(j))+"");		//ʿΨ
+			spFullMatrix.setCell(matrix.getRowLength()+2, j,getProblemAttentionCoefficient(getBaseCol(j))+"");		//շ
+			spFullMatrix.setCell(matrix.getRowLength()+3, j,getProblemAttentionMark(getBaseCol(j)));		//եޡ
+		}
+		
+		//ΤʿΨɲ
+		spFullMatrix.setCell(getStudentNumber()+1, getProblemNumber()+1, getAverage()+"");
+		return spFullMatrix;
+	}
+	
 /**
 * (ޤԿ)¿¤ؤޤ
 * @param totalArray ()줿
@@ -188,9 +257,9 @@ public class SPTable{
 * @param row ֹ¿¤ؤ
 * @return ¤ؤޥȥꥯ
 */
-	private Matrix getStudentChangeMatrix(Matrix baseMatrix,int[] row){
-		Matrix rowChangeMatrix = new Matrix();
-		rowChangeMatrix.MatrixCopy(baseMatrix);
+	private ArithmeticMatrix getStudentChangeMatrix(ArithmeticMatrix baseMatrix,int[] row){
+		ArithmeticMatrix rowChangeMatrix = new ArithmeticMatrix();
+		rowChangeMatrix.matrixCopy(baseMatrix);
 		int max = (int) baseMatrix.getRowSum(row[0]); //λ(ǼκǾ)
 		max++;
 		int roop = 1; //Ʊ³Ƥ뤫
@@ -241,9 +310,9 @@ public class SPTable{
 * @param col ֹԿ¿¤ؤ
 * @return ¤ؤޥȥꥯ
 */
-	private Matrix getProblemChangeMatrix(Matrix baseMatrix,int[] col){
-		Matrix colChangeMatrix = new Matrix();
-		colChangeMatrix.MatrixCopy(baseMatrix);
+	private ArithmeticMatrix getProblemChangeMatrix(ArithmeticMatrix baseMatrix,int[] col){
+		ArithmeticMatrix colChangeMatrix = new ArithmeticMatrix();
+		colChangeMatrix.matrixCopy(baseMatrix);
 		int max = (int) baseMatrix.getColSum(col[0]); //λ(ǼκǾ)
 		max++;
 		int roop = 1; //Ʊ³Ƥ뤫
@@ -295,7 +364,7 @@ public class SPTable{
 * @param studentB Ӥֹ2
 * @return ӷ̤ 1 < 2 λ True  1 >= 2 λ False ֤ޤ
 */
-	private boolean compareStudent(Matrix baseMatrix, int studentA, int studentB){
+	private boolean compareStudent(ArithmeticMatrix baseMatrix, int studentA, int studentB){
 		int studentATotal = 0; //̤
 		int studentBTotal = 0;
 		for (int i = 0; i < baseMatrix.getColLength(); i++){
@@ -313,7 +382,7 @@ public class SPTable{
 * @param problemB Ӥֹ2
 * @return ӷ̤ 1 < 2 λ True  1 >= 2 λ False ֤ޤ
 */
-	private boolean compareProblem(Matrix baseMatrix, int problemA, int problemB){
+	private boolean compareProblem(ArithmeticMatrix baseMatrix, int problemA, int problemB){
 		int problemATotal = 0; //ƤԿ
 		int problemBTotal = 0;
 		for (int i = 0; i < baseMatrix.getRowLength(); i++){
@@ -329,7 +398,7 @@ public class SPTable{
 * ꤷؽ()֤ޤ
 * @param row ꤷؽԤ¤ؤιֹ
 * @return ꤷؽԤ
-* @exception NotElementException ꤷؽԤ¸ߤʤ
+* @exception NotItemException ꤷؽԤ¸ߤʤ
 * @see #getProblemSum(int col)
 
 */
@@ -338,7 +407,7 @@ public class SPTable{
 			return (int)matrix.getRowSum(row);
 		}
 		else{
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 		}
 	}
 	
@@ -346,7 +415,7 @@ public class SPTable{
 * ꤷ()Կ֤ޤ
 * ꤹ¤ؤֹ
 * @return ꤷԿ
-* @exception NotElementException ꤷ꤬¸ߤʤ
+* @exception NotItemException ꤷ꤬¸ߤʤ
 * @see #getStudentSum(int row)
 */
 	public int getProblemSum(int col){
@@ -354,7 +423,7 @@ public class SPTable{
 			return (int)matrix.getColSum(col);
 		}
 		else{
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 		}
 	}
 	
@@ -392,7 +461,7 @@ public class SPTable{
 * ꤷؽ()Ψ֤ޤ
 * @param row ꤹؽԤ¤ؤιֹ
 * @return ꤷؽԤʿΨ
-* @exception NotElementException ꤷؽԤ¸ߤʤ
+* @exception NotItemException ꤷؽԤ¸ߤʤ
 * @see #getProblemAverage(int col)
 */
 	public double getStudentAverage(int row){
@@ -400,14 +469,14 @@ public class SPTable{
 			return getStudentSum(row) * 1.0 / getProblemNumber() * 100.0;
 		}
 		else{
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 		}
 	}
 /**
 * ꤷ()Ψ֤ޤ
 * @param col ꤹ¤ؤֹ
 * @return ꤷʿΨ
-* @exception NotElementException ꤷ꤬¸ߤʤ
+* @exception NotItemException ꤷ꤬¸ߤʤ
 * @see #getStudentAverage(int row)
 */
 	public double getProblemAverage(int col){
@@ -415,7 +484,7 @@ public class SPTable{
 			return getProblemSum(col) * 1.0 / getStudentNumber() * 100.0;
 		}
 		else{
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 		}
 	}
 	
@@ -465,7 +534,7 @@ public class SPTable{
 * ꤷؽ()շ֤ޤ
 * @param row ꤹؽԤ¤ؤιֹ
 * @return ꤷؽԤշ
-* @exception NotElementException ꤷؽԤ¸ߤʤ
+* @exception NotItemException ꤷؽԤ¸ߤʤ
 * @see #getProblemAttentionCoefficient(int col)
 */
 	public double getStudentAttentionCoefficient(int row){
@@ -523,7 +592,7 @@ public class SPTable{
 		return value;
 	}
 		else{
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 		}
 	}
 	
@@ -531,7 +600,7 @@ public class SPTable{
 * ꤷ()շ֤ޤ
 * @param col ꤹ¤ؤֹ
 * @return ꤷշ
-* @exception NotElementException ꤷ꤬¸ߤʤ
+* @exception NotItemException ꤷ꤬¸ߤʤ
 * @see #getStudentAttentionCoefficient(int row)
 */
 	public double getProblemAttentionCoefficient(int col){
@@ -589,7 +658,7 @@ public class SPTable{
 			return value;
 		}
 		else{
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 		}
 	}
 	
@@ -597,8 +666,9 @@ public class SPTable{
 * ؽԤեޡ֤ޤ
 * @param row ꤹؽԤ¤ؤιֹ
 * @return ꤷؽԤեޡ
-* @exception NotElementException ꤷؽԤ¸ߤʤ
+* @exception NotItemException ꤷؽԤ¸ߤʤ
 * @see #getProblemAttentionMark(int col)
+* @see #getStudentAttentionNumber(int row)
 */
 	public String getStudentAttentionMark(int row){
 		if (matrix.isRowNumber(row)){
@@ -625,7 +695,7 @@ public class SPTable{
 			return mark;
 		}
 		else{
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 		}
 	}
 	
@@ -633,8 +703,9 @@ public class SPTable{
 * եޡ֤ޤ
 * @param col ꤹ¤ؤֹ
 * @return ꤷեޡ
-* @exception NotElementException ꤷ꤬¸ߤʤ
+* @exception NotItemException ꤷ꤬¸ߤʤ
 * @see #getStudentAttentionMark(int row)
+* @see #getProblemAttentionNumber(int col)
 */
 	public String getProblemAttentionMark(int col){
 		if (matrix.isColNumber(col)){
@@ -661,7 +732,7 @@ public class SPTable{
 			return mark;
 	}
 		else{
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 		}
 	}
 	
@@ -670,10 +741,11 @@ public class SPTable{
 * ޡʤξ0`!'ξ1`!!'ξ2Ǽޤ
 * @param row ꤹؽԤ¤ؤιֹ
 * @return ꤷؽԤեޡ
-* @exception NotElementException ꤷؽԤ¸ߤʤ
+* @exception NotItemException ꤷؽԤ¸ߤʤ
 * @see #getProblemAttentionNumber(int col)
+* @see #getStudentAttentionMark(int row)
 */
-	private int getStudentAttentionNumber(int row){
+	public int getStudentAttentionNumber(int row){
 		if (matrix.isRowNumber(row)){
 		//շ
 		double attention = getStudentAttentionCoefficient(row);
@@ -697,7 +769,7 @@ public class SPTable{
 			return mark;
 		}
 		else{
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 		}
 	}
 	
@@ -706,10 +778,11 @@ public class SPTable{
 * ޡʤξ0`!'ξ1`!!'ξ2Ǽޤ
 * @param col ꤹ¤ؤֹ
 * @return ꤷեޡ
-* @exception NotElementException ꤷ꤬¸ߤʤ
+* @exception NotItemException ꤷ꤬¸ߤʤ
 * @see #getStudentAttentionNumber(int row)
+* @see #getProblemAttentionMark(int col)
 */
-	private int getProblemAttentionNumber(int col){
+	public int getProblemAttentionNumber(int col){
 		if (matrix.isColNumber(col)){
 		//շ
 		double attention = getProblemAttentionCoefficient(col);
@@ -734,7 +807,7 @@ public class SPTable{
 			return mark;
 		}
 		else{
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 		}
 	}
 	
@@ -742,7 +815,7 @@ public class SPTable{
 * S-PɽΥޥȥꥯ֤ޤ
 * @return S-PɽΥޥȥꥯ
 */
-	public Matrix getBaseSPMatrix(){
+	public ArithmeticMatrix getBaseSPMatrix(){
 		return matrix;
 	}
 	
@@ -768,7 +841,7 @@ public class SPTable{
 * ꤷԤS-PɽΥޥȥꥯǤϲܤˤäιֹ֤ޤ
 * @param row S-Pɽˤֹ
 * @return ɽˤֹ
-* @exception NotElementException ꤵ줿ֹ椬¸ߤʤ
+* @exception NotItemException ꤵ줿ֹ椬¸ߤʤ
 * @see #getBaseCol(int col)
 * @see #getBaseRowArray()
 */
@@ -777,7 +850,7 @@ public class SPTable{
 		return baseRow[row];
 		}
 		else{
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 		}
 	}
 	
@@ -795,7 +868,7 @@ public class SPTable{
 * ꤷS-PɽΥޥȥꥯǤϲܤˤäֹ֤ޤ
 * @param col S-Pɽˤֹ
 * @return ɽˤֹ
-* @exception NotElementException ꤵ줿ֹ椬¸ߤʤ
+* @exception NotItemException ꤵ줿ֹ椬¸ߤʤ
 * @see #getBaseRow(int row)
 * @see #getBaseColArray()
 */
@@ -804,7 +877,7 @@ public class SPTable{
 		return baseCol[col];
 		}
 			else{
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 		}
 	}
 	
@@ -822,7 +895,7 @@ public class SPTable{
 * ꤷԤS-PɽΥޥȥꥯǤϲܤˤ뤫ֹ֤ޤ
 * @param row ɽˤֹ
 * @return S-Pɽˤֹ
-* @exception NotElementException ꤵ줿ֹ椬¸ߤʤ
+* @exception NotItemException ꤵ줿ֹ椬¸ߤʤ
 */
 	private int getSPRow(int row){
 		if (matrix.isRowNumber(row)){ //ޥȥꥯϰ⤫ɤĴ٤
@@ -832,14 +905,14 @@ public class SPTable{
 				}
 			}
 		}
-			throw new NotElementException("row("+ row +")");
+			throw new NotItemException("row("+ row +")");
 	}
 	
 /**
 * ꤷS-PɽΥޥȥꥯǤϲܤˤ뤫ֹ֤ޤ
 * @param col ɽˤֹ
 * @return S-Pɽˤֹ
-* @exception NotElementException ꤵ줿ֹ椬¸ߤʤ
+* @exception NotItemException ꤵ줿ֹ椬¸ߤʤ
 */
 	private int getSPCol(int col){
 		if (matrix.isColNumber(col)){ //ޥȥꥯϰ⤫ɤĴ٤
@@ -849,23 +922,23 @@ public class SPTable{
 				}
 			}
 		}
-			throw new NotElementException("col("+ col +")");
+			throw new NotItemException("col("+ col +")");
 	}
 	
 /**
 * S-PɽΥޥȥꥯꤷޤ
 * @param baseMatrix Ԥޥȥꥯ
 */
-	private void setBaseMatrix(Matrix baseMatrix){
-		matrix = new Matrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
-		matrix.MatrixCopy(baseMatrix);
+	private void setBaseMatrix(ArithmeticMatrix baseMatrix){
+		matrix = new ArithmeticMatrix(baseMatrix.getRowLength(), baseMatrix.getColLength());
+		matrix.matrixCopy(baseMatrix);
 	}
 	
 /**
 * ¤ؤιֹݻޤ
 * @param baseMatrix ʬоݤΥޥȥꥯ
 */
-	private void setBaseRow(Matrix baseMatrix){
+	private void setBaseRow(ArithmeticMatrix baseMatrix){
 		baseRow = new int[baseMatrix.getRowLength()];
 	}
 	
@@ -873,7 +946,7 @@ public class SPTable{
 * ¤ؤֹݻޤ
 * @param baseMatrix ʬоݤΥޥȥꥯ
 */
-	private void setBaseCol(Matrix baseMatrix){
+	private void setBaseCol(ArithmeticMatrix baseMatrix){
 		baseCol = new int[baseMatrix.getColLength()];
 	}
 	
@@ -881,7 +954,7 @@ public class SPTable{
 * S-Pɽ븵ȤʤޥȥꥯꤷS-Pɽޤ
 * @param baseMatrix ԤȤʤޥȥꥯ
 */
-	public void setSPMatrix(Matrix baseMatrix){
+	public void setSPMatrix(ArithmeticMatrix baseMatrix){
 		setBaseMatrix(baseMatrix);
 		setBaseRow(matrix);
 		setBaseCol(matrix);
@@ -893,11 +966,17 @@ public class SPTable{
 * @param col Ǥ
 * @param value 
 * @exception NotElementException ꤷǤ¸ߤʤ
-* @see #setSPMatrix(Matrix baseMatrix)
+* @exception ValueFormatException ͤ0ޤ1ʳͤǤ
+* @see #setSPMatrix(ArithmeticMatrix baseMatrix)
 */
 	public void setElement(int row, int col, int value){
 		if (matrix.isMatrixEntityPoint(row, col)){
-			matrix.setCell(row, col, value);
+			if(value == 0.0 || value == 1.0){
+				matrix.setCell(row, col, value);
+			}
+			else{
+				throw new ValueFormatException("value("+value+")");
+			}
 		}
 		else{
 			throw new NotElementException("Point(" + row + "," + col + ")");
